@@ -78,8 +78,6 @@ def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organi
                 if pValueList[i]<pValueAccepted:
                         listRedRectangles.append(Rectangle((posList[i]/lengthGenome,startingY), width=(posList[i+1]-posList[i])/lengthGenome,height=redRectanglesHeight,color=redRectanglesColor))
                         
-        print(posList[0])
-        print(posList[-1])
         
         #Ticks
         listTicks=[]
@@ -96,7 +94,7 @@ def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organi
         
         
         #Creating the figure
-        fig=plt.figure()#figsize=(blueRectangleLength*2,blueRectangleHeight*2))
+        fig=plt.figure(figsize=(20,4))#figsize=(blueRectangleLength*2,blueRectangleHeight*2))
         ax=fig.add_subplot(111)
         
         #Annotations
